@@ -289,23 +289,24 @@ chmod 0700 {hook_path}
         # We want to shutdown properly after installing. This is safe to set
         # here as subsequent boots will ignore this setting, letting us use the
         # vm ;)
-        if self.conf.get('vm.release') in ('precise', 'quantal'):
-            # Curse cloud-init lack of compatibility
-            self.append_cmd('halt')
-        else:
-            self.set('power_state', None, {'mode': 'poweroff'})
+        if self.conf.get('vm.poweroff'):
+            if self.conf.get('vm.release') in ('precise', 'quantal'):
+                # Curse cloud-init lack of compatibility
+                self.append_cmd('halt')
+            else:
+                self.set('power_state', None, {'mode': 'poweroff'})
 
     def populate(self):
         # Common and non-configurable options
+        self.set('manage_etc_hosts', None, True)
+        self.set('chpasswd', None, dict(expire=False))
+        # Configurable options
         if self.conf.get('vm.release') == 'precise':
             # Curse cloud-init lack of compatibility
             msg = 'uci-vms finished installing in $UPTIME seconds.'
         else:
             msg = 'uci-vms finished installing in ${uptime} seconds.'
         self.set('final_message', None, msg)
-        self.set('manage_etc_hosts', None, True)
-        self.set('chpasswd', None, dict(expire=False))
-        # Configurable options
         self.set('password', 'vm.password')
         self.set_list_of_paths('ssh_authorized_keys', 'vm.ssh_authorized_keys')
         self.set_ssh_keys()
@@ -349,6 +350,7 @@ class VM(object):
         # Seed files
         self._meta_data_path = None
         self._user_data_path = None
+        self.ci_user_data = None
 
     def _download_in_cache(self, source_url, name, force=False):
         """Download ``name`` from ``source_url`` in ``vm.download_cache``.
@@ -435,6 +437,7 @@ class VM(object):
                                             'user-data')
         with open(self._user_data_path, 'w') as f:
             f.write(ci_user_data.dump())
+        self.ci_user_data = ci_user_data
 
     def download(self, force=False):
         raise NotImplementedError(self.download)
